import { produce } from 'immer';
import theme from '../../../../theme';
import { Container, Stack } from '../../../layout';
import { Title, Paragraph } from '../../atoms';
import { ParagraphProps } from '../../atoms/Paragraph/Paragraph';
import { TitleProps } from '../../atoms/Title/Title';
import { TextInput, Button } from '../../molecules';
import { ButtonProps } from '../../molecules/Button/Button';
import { TextInputProps } from '../../molecules/TextInput/TextInput';

export interface ApplyForm4Props {
  titleProps?: TitleProps;
  subTitleProps?: TitleProps;
  inputProps?: TextInputProps;
  descriptionProps?: ParagraphProps;
  buttonProps?: ButtonProps;
  backgroundColor?: string;
  isMobile?: boolean;
}

export default function ApplyForm4(props: ApplyForm4Props) {
  const { titleProps, subTitleProps, inputProps, descriptionProps, buttonProps, backgroundColor, isMobile } = props;

  return (
    <Container direction="column" backgroundColor={backgroundColor} isCenter={true} isMobile={isMobile} padding="80px 0">
      <Stack direction="column" gap={48}>
        <Stack direction="column" alignItems="center" gap={8}>
          <Title {...titleProps} isMobile={isMobile} />
          <Title {...subTitleProps} isMobile={isMobile} />
        </Stack>
        <Stack direction="column" gap={8}>
          <Stack direction={isMobile ? 'column' : 'row'} width="100%" gap={12} alignItems="center">
            <TextInput {...inputProps} />
            <Button {...buttonProps} isFullWidth={isMobile} />
          </Stack>
          <Paragraph {...descriptionProps} isMobile={isMobile} />
        </Stack>
      </Stack>
    </Container>
  );
}

ApplyForm4.defaultProps = {
  titleProps: produce(Title.defaultProps, draft => {
    draft.size = 'lg';
    draft.content = '제일 먼저 서비스를 이용하세요!';
    draft.textAlign = 'center';
  }),
  subTitleProps: produce(Title.defaultProps, draft => {
    draft.fontWeight = 'normal';
    draft.size = 'sm';
    draft.content = '연락처를 남겨주시면, 정식 오픈 시에 제일 먼저 출시 완료 문자를 보내드릴게요.';
    draft.textAlign = 'center';
  }),
  inputProps: produce(TextInput.defaultProps, draft => {
    draft.isActiveDeleteIcon = false;
    draft.placeholder.text = '연락처를 작성해주세요.';
    draft.isFullWidth = true;
  }),
  buttonProps: produce(Button.defaultProps, draft => {
    draft.content = '제출';
  }),
  descriptionProps: produce(Paragraph.defaultProps, draft => {
    draft.fontWeight = 'normal';
    draft.size = 'sm';
    draft.content = '‼️ 연락처는 문자 메시지 발송에만 사용되며, 문자 발송 후 파기하여 저장하지 않아요.';
  }),
  backgroundColor: theme.colors.gray50,
  isMobile: false,
};
