import { motion } from 'framer-motion';
import { produce } from 'immer';
import styled, { css } from 'styled-components';
import { isEmpty } from 'lodash-es';
import { Container } from '../../../layout';
import Title, { TitleProps } from '../../atoms/Title/Title';
import Carousel1, { CarouselProps } from '../Carousel1/Carousel1';
import { Card1 } from '../../organisms';

export interface Review5Props {
  slides: React.ReactNode[];
  titleProps: TitleProps;
  carouselProps: CarouselProps;
  backgroundColor?: string;
  isMobile?: boolean;
  gap?: number;
  padding?: {
    left?: number;
    right?: number;
    top?: number;
    bottom?: number;
  };
}

// Title + Carousel
export default function Review5(props: Review5Props) {
  const slides = !isEmpty(props.slides) ? props.slides : [];

  return (
    <ReviewBox backgroundColor={props.backgroundColor} padding={props?.padding} isMobile={props.isMobile}>
      <Container isMobile={props.isMobile} direction="column" isCenter={true} backgroundColor={props.backgroundColor} padding={`0 0 ${props.gap}px 0`}>
        <Title {...props.titleProps} isMobile={props.isMobile} />
      </Container>
      <CarouselBox isMobile={props.isMobile}>
        <Carousel1 {...props.carouselProps} slides={slides}></Carousel1>
      </CarouselBox>
    </ReviewBox>
  );
}

Review5.defaultProps = {
  titleProps: produce(Title.defaultProps, draft => {
    draft.content = '1인 기업부터 연매출 40억 기업까지,\n 80개의 기업이 인정했습니다.';
    draft.size = 'lg';
    draft.textAlign = 'center';
  }),
  carouselProps: produce(Carousel1.defaultProps, draft => {
    draft.slidesPerView = 3.5;
    draft.padding.left = 92;
    draft.pagination = true;
  }),
  slides: Array(5).fill(<Card1 />),
  backgroundColor: '#FFEBCB',
  gap: 64,
  padding: {
    top: 80,
    bottom: 80,
    right: 0,
    left: 0,
  },
  isMobile: false,
};

const CarouselBox = styled.div<any>`
  width: 100%;
  ${props => {
    return (
      props.isMobile &&
      `
                overflow: hidden;
            `
    );
  }}
  overflow: hidden;
`;

const ReviewBox = styled(motion.div)<any>`
  width: 100%;
  background-color: ${props => props.backgroundColor};
  padding-left: ${props => props?.padding?.left}px;
  padding-right: ${props => props?.padding?.right}px;
  padding-top: ${props => props?.padding?.top}px;
  padding-bottom: ${props => props?.padding?.bottom}px;
  ${props => {
    return (
      props.isMobile &&
      `
            max-width: 375px;
        `
    );
  }};
  margin: 0 auto;
`;
