import styled from 'styled-components';
import { motion, AnimatePresence } from 'framer-motion';
import { useInView } from 'react-intersection-observer';
import { Container, Stack } from '../../../layout';
import Paragraph from '../../atoms/Paragraph/Paragraph';
import Title from '../../atoms/Title/Title';

export interface TextSection1Props {
  isMobile?: boolean;
}

export default function TextSection1(props: TextSection1Props) {
  const { isMobile } = props;
  const { ref, inView } = useInView({
    threshold: 0.1, // 요소가 10% 이상 화면에 들어오면 감지
  });

  const variants = {
    initial: { opacity: 0, y: 50 },
    animate: { opacity: 1, y: 0 },
    exit: { opacity: 0, y: -50 },
  };

  const textList = ['"목표나 계획 없이 주먹구구식으로 일하고 있어요."', '"프로젝트 일정을 한 눈에 파악하기 어려워요."'];

  return (
    <Box ref={ref}>
      <Container isMobile={isMobile}>
        <Stack gap={56} justifyContent="center">
          <TitleArea>
            <Title size="md" content="아직도 제대로 된 체계 없이 주먹구구식으로 일하고 계신가요?" />
          </TitleArea>
          <DetailArea>
            {textList.map(text => {
              return (
                <AnimatedParagraph
                  content={text}
                  variants={variants}
                  initial="hidden"
                  animate={inView ? 'visible' : 'hidden'}
                  transition={{
                    duration: 0.5,
                    ease: 'easeOut',
                  }}
                />
              );
            })}
          </DetailArea>
        </Stack>
      </Container>
    </Box>
  );
}

TextSection1.defaultProps = {};

const Box = styled(motion.div)<any>`
  display: flex;
`;

const TitleArea = styled(motion.div)<any>`
  flex: 1;
  display: flex;
  justify-content: center;
`;

const DetailArea = styled(motion.div)<any>`
  flex: 1;
  display: flex;
  flex-direction: column;
  align-items: flex-start;
`;

const AnimatedParagraph = styled(Paragraph)<any>``;
