import styled from 'styled-components';
import { motion } from 'framer-motion';
import { produce } from 'immer';
import theme from '../../../../theme';
import { Container, Stack } from '../../../layout';
import { Title, Paragraph } from '../../atoms';
import { ParagraphProps } from '../../atoms/Paragraph/Paragraph';
import { TitleProps } from '../../atoms/Title/Title';
import { isEmpty } from 'lodash-es';

export interface TextSection2Props {
  isMobile?: boolean;
  subTitleProps?: TitleProps;
  titleProps?: TitleProps;
  features?: { titleProps: TitleProps; descriptionProps: ParagraphProps }[];
  backgroundImage?: string;
  backgroundColor?: string;
  contentBackgroundColor?: string;
  contentPadding?: { top?: number; bottom?: number; left?: number; right?: number; isApply?: boolean };
}

export default function TextSection2(props: TextSection2Props) {
  const { isMobile, subTitleProps, titleProps, features, backgroundImage, backgroundColor, contentBackgroundColor, contentPadding } = props;

  return (
    <Container isMobile={isMobile} backgroundColor={backgroundColor} backgroundImage={backgroundImage}>
      <ContentBox isMobile={isMobile} backgroundColor={contentBackgroundColor} padding={contentPadding}>
        <Stack direction="column" gap={40}>
          <Stack direction="column" gap={8} alignItems="center">
            <Title {...subTitleProps} isMobile={isMobile} />
            <Title {...titleProps} isMobile={isMobile} />
          </Stack>
          {!isEmpty(features) && (
            <Stack direction={isMobile ? 'column' : 'row'} gap={isMobile ? 32 : 40}>
              {features?.map((feature, index) => {
                const titleProps = feature?.titleProps;
                const descriptionProps = feature?.descriptionProps;
                return (
                  <Stack direction="column" gap={isMobile ? 12 : 24} key={index}>
                    <Title {...titleProps} isMobile={isMobile} />
                    <Paragraph {...descriptionProps} isMobile={isMobile} />
                  </Stack>
                );
              })}
            </Stack>
          )}
        </Stack>
      </ContentBox>
    </Container>
  );
}

TextSection2.defaultProps = {
  subTitleProps: produce(Title.defaultProps, draft => {
    draft.content = 'Subtitle 서브타이틀';
    draft.size = 'sm';
    draft.fontWeight = 'normal';
  }),
  titleProps: produce(Title.defaultProps, draft => {
    draft.content = 'Title 타이틀';
    draft.size = 'lg';
    draft.fontWeight = 'normal';
  }),
  features: Array(3).fill({
    titleProps: produce(Title.defaultProps, draft => {
      draft.content = 'Feature Title 01';
      draft.size = 'md';
      draft.fontWeight = 'bold';
    }),
    descriptionProps: produce(Paragraph.defaultProps, draft => {
      draft.content = '콘텐츠와 지도를 이어 풍성한 정보와 재미를 줍니다. 지도 기반의 알고리즘을 통해 더 많은 팔로워를 확보해보세요. 시그니처 스탬프, 광고를 활용하여 수익을 개선해보세요.';
      draft.size = 'md';
      draft.fontWeight = 'normal';
    }),
  }),
  backgroundImage: '',
  backgroundColor: 'transparent',
  contentBackgroundColor: theme.colors.gray50,
  contentPadding: {
    top: 64,
    bottom: 64,
    left: 80,
    right: 80,
    isApply: false,
  },
  isMobile: false,
};

const ContentBox = styled(motion.div)<any>`
  display: flex;
  width: 100%;
  background: ${props => props.backgroundColor};
  border-radius: 20px;
  padding: ${props => (props.isMobile ? '64px 16px' : '64px 80px')};
  ${({ padding }) => padding?.isApply && `padding-top: ${padding?.top}px;`}
  ${({ padding }) => padding?.isApply && `padding-bottom: ${padding?.bottom}px;`}
  ${({ padding }) => padding?.isApply && `padding-left: ${padding?.left}px;`}
  ${({ padding }) => padding?.isApply && `padding-right: ${padding?.right}px;`}  
  overflow: hidden;
`;
